	subroutine linsystemC1 (eps,n,xx,px,c)

!
!	Forming and solving the system of linear equations, comming from 
!	the collocation method with Chebyshev tension splines at the 
!	generalized Gaussian points. The differential equation is given with
!	eps*u''(x)+bb(x,eps)*u'(x)+cc(x,eps)*u(x)=ff(x,eps),
!	and boundary values with
!	u(ax)=alpha(eps), u(bx)=beta(eps).
!	eps is assumed to be positive.
!
!   INPUT:
!       eps	  = double precision variable, the leading coefficient 
!				in the differential equation, assumed to be positive
!		n	  = integer variable, the number of the nontrivial 
!				subintervals in [ax,bx]
!
!   OUTPUT:
!       xx    = rank-one double precision array of size n+3, the
!               array of knots defined as:
!               xx(1)=xx(2)=ax, xx(n+2)=xx(n+3)=bx, and 
!				xx(i+2)=ax*(n-i)/n+bx*i/n for i=1,...,n-1;
!               the associated extended partition T has all interior
!               knots of multiplicity 2, and the boundary points
!               of multiplicity 4
!       px    = rank-one double precision array of size n+2, the
!               array of tension parameters, px(i)>=0 is the tension 
!				parameter on the subinterval [xx(i),xx(i+1));
!               for the choice of the parameters see Example 8.1
!       c     = rank-one double precision array of size 2*n+2,
!               the array of de Boor points associated with the
!               extended partition T;
!               c(i) corresponds to the B-spline with the support
!               [T(i),T(i+4)];
!				c is the solution of the linear system 
!

	
	use examplediffeqC1

	implicit none

	double precision, intent(in) :: eps
	integer, intent(in) :: n
	double precision, intent(out) :: xx(n+3),px(n+2),c(2*n+2)

	double precision :: a(5,2*n+2),f(2*n+2),cx(4,-3:0)
	double precision :: h,gp,t1,t2,lspl1(4),lspl2(4) 
	integer ::i,nn,j
	double precision, external :: gausspoints	

!
!	Defining the dimension of the linear system
!
	nn=2*n+2
!
!	Defining the array of knots
!
	xx(1:2)=ax
	do i=1,n-1
		xx(i+2)=ax*(n-dble(i))/n+bx*dble(i)/n
	enddo
	xx(n+2:n+3)=bx
!
!	The choice of the tension parameters
!
	call pchoiceC1(eps,xx,n+3,px)

	h=(bx-ax)/n

!
!	Forming the matrix of the linear system in band storage mode,
!	and the vector containing the right-hand sides of the linear
!	system
!	
	a=0.0d0
	a(3,1)=1.0d0
	f(1)=alpha(eps)

	cx=0.0d0
	do i=-3,0
		cx(i+4,i)=1.0d0
	enddo
	do i=0,n-1
!
!	Calculating the generalized Gaussian points
!
		gp=gausspoints(px(i+2),h)
		t1=xx(i+2)+gp
		t2=xx(i+3)-gp
		call diffopC1 (t1,xx,px,i+2,cx,4,eps,lspl1)
		call diffopC1 (t2,xx,px,i+2,cx,4,eps,lspl2) 
		do j=1,4
			a(5-j,2*i+j)=lspl1(j)
			a(6-j,2*i+j)=lspl2(j)
		enddo 
		f(2*(i+1))=ff(t1,eps)
		f(2*(i+1)+1)=ff(t2,eps)
	enddo
	a(3,nn)=1.0d0
	f(nn)=beta(eps)
!
!	Calling the IMSL subroutine for solving a real system of linear 
!	equations in band storage mode with iterative refinement
!
	call DLSARB (nn,a,5,2,2,f,1,c)


	end subroutine linsystemC1