	subroutine tension2der4C1 (x,xx,px,ileft,cx,dim,spl)

!
!   Calculating the second derivative of the Chebyshev tension
!   spline curve
!
!   INPUT:
!       x     = double precision variable, the point at which the
!               second derivative of the spline curve is evaluated
!       xx    = rank-one double precision array of size dimx, the
!               increasing array of knots, assumed to fulfill the
!               conditions:
!               xx(1)=xx(2)<xx(3)<...<xx(i)<xx(i+1)<...<xx(dimx-1)=
!               xx(dimx); xx(3),...,xx(dimx-2) is the partition of
!               [xx(1),xx(dimx)]; the associated extended
!               partition T has all interior knots of multiplicity 2,
!               and the boundary points of multiplicity 4
!       px    = rank-one double precision array of size dimx-1, the
!               array of tension parameters, assumed to be
!               nonnegative: px(i)>=0 is the tension parameter on
!               the subinterval [xx(i),xx(i+1));
!               px(1) and px(dimx-1) can be arbitrary
!       ileft = integer variable, the index of the array xx such
!               that x is contained in the subinterval
!               [xx(ileft),xx(ileft+1)]
!       cx    = rank-two double precision array of shape dim by
!               2*dimx-4, the array of de Boor points of the
!               Chebyshev tension spline, associated with the
!               extended partition T;
!               cx(1:dim,i) corresponds to the B-spline with the
!               support [T(i),T(i+4)]
!       dim   = integer variable, the extent of the first dimension
!               in the array cx, assumed to be positive
!
!   AUXILIARY TERM:
!      dimx   = size(xx)
!
!   OUTPUT:
!       spl   = rank-one double precision array of size dim, the
!               output value of the second derivative of the
!               Chebyshev tension spline curve at the point x
!

	use functions

	implicit none

	integer, intent(in) :: ileft,dim
	double precision, intent(in) :: x,xx(*),px(*),cx(dim,*)	!xx(dimx),px(dimx-1),cx(dim,2*dimx-4)
	double precision, intent(out) :: spl(dim)

	double precision, parameter :: zero=0.0d0
	double precision :: t(-1:2),p(-1:1),c(dim,-3:0)	! t(0)<=x<=t(1)
	double precision :: h(-1:1),kc2ph
	integer :: ileftc,i

!
!	Storing only relevant data
!
	t(-1:2)=xx(ileft-1:ileft+2)
	p(-1:1)=px(ileft-1:ileft+1)
	ileftc=2*ileft
	c(1:dim,-3:0)=cx(1:dim,ileftc-3:ileftc)
!
!	Calculating the length of the subintervals involved
!
	do i=-1,1
		h(i)=t(i+1)-t(i)
	enddo
!
!   Calculating the de Boor points of the first derivative
!
	c(1:dim,0)=(c(1:dim,0)-c(1:dim,-1))/CC3(h(0),zero,h(1),p(0),zero ,p(1))
	c(1:dim,-1)=(c(1:dim,-1)-c(1:dim,-2))*2/CC3(zero,h(0),zero,zero,p(0),zero)/ &
				(1.0d0+exp(-p(0)*h(0)))
	c(1:dim,-2)=(c(1:dim,-2)-c(1:dim,-3))/CC3(h(-1),zero,h(0),p(-1),zero,p(0))
!
!   Calculating the de Boor points of the second derivative
!
	kc2ph=h(0)*KC2(p(0)*h(0)/2)/2
	do i=0,-1,-1
		c(1:dim,i)=(c(1:dim,i)-c(1:dim,i-1))/kc2ph
	enddo
!
!   Calculating the value of the second derivative of the Chebyshev
!   tension spline curve as the linear combination of the second
!   order B-splines
!
	call tension2(x,t,p,2,c(1:dim,-1:0),2,dim,spl)


	end subroutine tension2der4C1