	subroutine tension3C1 (x,xx,px,ileft,cx,dim,spl)

!
!   Generalized de Boor algorithm for calculating the third order
!   Chebyshev tension spline curve, i.e. a spline curve associated
!   with the first reduced system of Chebyshev tension splines
!
!   INPUT:
!       x     = double precision variable, the point at which the
!               spline curve is evaluated
!       xx    = rank-one double precision array of size dimx, the
!               increasing array of knots, assumed to fulfill the
!               conditions:
!               xx(1)=xx(2)<xx(3)<...<xx(i)<xx(i+1)<...<xx(dimx-1)=
!               xx(dimx); xx(3),...,xx(dimx-2) is the partition of
!               [xx(1),xx(dimx)]; the associated extended
!               partition T has all interior knots of multiplicity 2,
!               and the boundary points of multiplicity 4
!       px    = rank-one double precision array of size dimx-1, the
!               array of tension parameters, assumed to be
!               nonnegative: px(i)>=0 is the tension parameter on
!               the subinterval [xx(i),xx(i+1));
!               px(1) and px(dimx-1) can be arbitrary
!       ileft = integer variable, the index of the array xx such
!               that x is contained in the subinterval
!               [xx(ileft),xx(ileft+1)]
!       cx    = rank-two double precision array of shape dim by
!               2*dimx-4, the array of de Boor points of the third
!               order Chebyshev tension spline, associated with the
!               extended partition T;
!               cx(1:dim,i) corresponds to the B-spline with the
!               support [T(i),T(i+3)], so cx(1:dim,1) can be
!               arbitrary
!       dim   = integer variable, the extent of the first dimension
!               in the array cx, assumed to be positive
!
!   AUXILIARY TERM:
!      dimx   = size(xx)
!
!   OUTPUT:
!       spl   = rank-one double precision array of size dim, the
!               output value of the spline curve associated with
!               the first reduced system at the point x
!

	use functions

	implicit none

	integer, intent(in) :: ileft,dim
	double precision, intent(in) :: x,xx(*),px(*),cx(dim,*)	
	double precision, intent(out) :: spl(dim)

	double precision :: t(0:1),p,c(dim,-2:0)	!t(0)<=x<=t(1)
	double precision :: temp1,temp2,temp3,h,xa,xb,temp
	integer :: ileftc

!
!	Storing only relevant data
!
	t(0:1)=xx(ileft:ileft+1)
	p=px(ileft)
	ileftc=2*ileft
	c(1:dim,-2:0)=cx(1:dim,ileftc-2:ileftc)
!
!	Calculating the length of subintervals involved
!
	h=t(1)-t(0)
	xa=x-t(0)
	xb=t(1)-x
!
!   If x is equal to the left end point of subinterval
!   [xx(ileft),xx(ileft+1)], then the value of the spline at x is
!   equal to the de Boor point cx(ileft-2)...
!
	if (x==t(0)) then
		spl=c(1:dim,-2)
		return
!
!   ... and also if x is equal to the right end point, then the
!   spline is equal to the cx(ileft)
!
	elseif (x==t(1)) then
		spl=c(1:dim,0)
		return
	endif
!
!   If x is in the interior of [xx(ileft),xx(ileft+1)], then the
!   generalized de Boor algorithm of order 3 is performed, where the
!   point x is inserted 2 times
!
	temp=divth1(xb/2,h/2,p)
	temp1=exp(-p*xa)*u(xb,xa,p)*temp
	temp2=2*temp*divth2(xa/2,xb/2,h/2,p)
	temp3=exp(-p*xb)*u(xa,xb,p)*divth1(xa/2,h/2,p)
!
!	The final value of the spline curve
!
	spl=c(1:dim,-2)*temp1+c(1:dim,-1)*temp2+c(1:dim,0)*temp3


	end subroutine tension3C1